@@ -36,14 +36,12 @@ class KActionMenu;
 class KToggleAction;
 
 namespace Konsole {
-class IncrementalSearchBar;
 class ViewManager;
 class ViewProperties;
 class Session;
 class SessionController;
 class ProfileList;
 class BookmarkHandler;
-class TabbedViewContainer;
 
 /**
  * The main window.  This contains the menus and an area which contains the terminal displays.
@@ -147,7 +145,7 @@ private Q_SLOTS:
     void newWindow();
     void showManageProfilesDialog();
     void activateMenuBar();
-    void showSettingsDialog(const bool showProfilePage = false);
+    void showSettingsDialog(bool showProfilePage = false);
     void showShortcutsDialog();
     void newFromProfile(const Profile::Ptr &profile);
     void activeViewChanged(SessionController *controller);
