@@ -44,6 +44,7 @@
 #include <KShell>
 #include <KProcess>
 #include <KConfigGroup>
+#include <KIO/DesktopExecParser>
 
 // Konsole
 #include <sessionadaptor.h>
@@ -382,7 +383,7 @@ QString Session::checkProgram(const QString& program)
         return exec;
     }
 
-    exec = KRun::binaryName(exec, false);
+    exec = KIO::DesktopExecParser::executablePath(exec);
     exec = KShell::tildeExpand(exec);
     const QString pexec = QStandardPaths::findExecutable(exec);
     if (pexec.isEmpty()) {
@@ -494,7 +495,7 @@ void Session::run()
 
     int result = _shellProcess->start(exec, arguments, _environment);
     if (result < 0) {
-        terminalWarning(i18n("Could not start program '%1' with arguments '%2'.", exec, arguments.join(QLatin1String(" "))));
+        terminalWarning(i18n("Could not start program '%1' with arguments '%2'.", exec, arguments.join(QLatin1Char(' '))));
         terminalWarning(_shellProcess->errorString());
         return;
     }
@@ -1116,6 +1117,7 @@ QString Session::getDynamicTitle()
      * <br>
      * The markers recognized are:
      * <ul>
+     * <li> %B - User's Bourne prompt sigil ($, or # for superuser). </li>
      * <li> %u - Name of the user which owns the process. </li>
      * <li> %n - Replaced with the name of the process.   </li>
      * <li> %d - Replaced with the last part of the path name of the
@@ -1129,6 +1131,20 @@ QString Session::getDynamicTitle()
      */
     QString title = tabTitleFormat(Session::LocalTabTitle);
     // search for and replace known marker
+
+    int UID = process->userId(&ok);
+    if(!ok) {
+        title.replace(QLatin1String("%B"), QStringLiteral("-"));
+    } else {
+        //title.replace(QLatin1String("%I"), QString::number(UID));
+        if (UID == 0) {
+            title.replace(QLatin1String("%B"), QStringLiteral("#"));
+        } else {
+            title.replace(QLatin1String("%B"), QStringLiteral("$"));
+        }
+    }
+
+
     title.replace(QLatin1String("%u"), process->userName());
     title.replace(QLatin1String("%h"), Konsole::ProcessInfo::localHost());
     title.replace(QLatin1String("%n"), process->name(&ok));
@@ -1144,17 +1160,15 @@ QString Session::getDynamicTitle()
         title.replace(QLatin1String("%d"), QStringLiteral("-"));
         title.replace(QLatin1String("%D"), QStringLiteral("-"));
     } else {
-        if (title.contains(QLatin1String("%D"))) {
-            const QString homeDir = process->userHomeDir();
-            if (!homeDir.isEmpty()) {
-                // Change User's Home Dir w/ ~ only at the beginning
-                if (dir.startsWith(homeDir)) {
-                    dir.remove(0, homeDir.length());
-                    dir.prepend(QLatin1Char('~'));
-                }
+        // allow for shortname to have the ~ as homeDir
+        const QString homeDir = process->userHomeDir();
+        if (!homeDir.isEmpty()) {
+            if (dir.startsWith(homeDir)) {
+                dir.remove(0, homeDir.length());
+                dir.prepend(QLatin1Char('~'));
             }
-            title.replace(QLatin1String("%D"), dir);
         }
+        title.replace(QLatin1String("%D"), dir);
         title.replace(QLatin1String("%d"), process->formatShortDir(dir));
     }
 
@@ -1582,6 +1596,10 @@ int Session::historySize() const
     }
 }
 
+QString Session::profile()
+{
+    return SessionManager::instance()->sessionProfile(this)->name();
+}
 
 void Session::setProfile(const QString &profileName)
 {
